@@ -1,4 +1,4 @@
-## Copyright (C) 1996, 1997, 2002, 2004, 2005, 2006, 2007 John W. Eaton
+## Copyright (C) 1996-2013 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -18,9 +18,8 @@
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} issquare (@var{x})
-## If @var{x} is a square matrix, then return the dimension of @var{x}.
-## Otherwise, return 0.
-## @seealso{size, rows, columns, length, ismatrix, isscalar, isvector}
+## Return true if @var{x} is a square matrix.
+## @seealso{isscalar, isvector, ismatrix, size}
 ## @end deftypefn
 
 ## Author: A. S. Hodel <scotte@eng.auburn.edu>
@@ -29,17 +28,36 @@
 
 function retval = issquare (x)
 
-  retval = 0;
-
-  if (nargin == 1)
-    if (ismatrix (x) && ndims (x) < 3)
-      [nr, nc] = size (x);
-      if (nr == nc && nr > 0)
-        retval = nr;
-      endif
-    endif
-  else
+  if (nargin != 1)
     print_usage ();
   endif
 
+  if (ndims (x) == 2)
+    [r, c] = size (x);
+    retval = r == c;
+  else
+    retval = false;
+  endif
+
 endfunction
+
+
+%!assert (issquare ([]))
+%!assert (issquare (1))
+%!assert (! issquare ([1, 2]))
+%!assert (issquare ([1, 2; 3, 4]))
+%!assert (! issquare ([1, 2; 3, 4; 5, 6]))
+%!assert (! issquare (ones (3,3,3)))
+%!assert (issquare ("t"))
+%!assert (! issquare ("test"))
+%!assert (issquare (["test"; "ing"; "1"; "2"]))
+%!test
+%! s.a = 1;
+%! assert (issquare (s));
+%!assert (issquare ({1, 2; 3, 4}))
+%!assert (sparse (([1, 2; 3, 4])))
+
+%% Test input validation
+%!error issquare ()
+%!error issquare ([1, 2; 3, 4], 2)
+
