@@ -1,4 +1,4 @@
-## Copyright (C) 2000-2012 Kai Habel
+## Copyright (C) 2000-2013 Kai Habel
 ##
 ## This file is part of Octave.
 ##
@@ -19,14 +19,14 @@
 ## -*- texinfo -*-
 ## @deftypefn  {Function File} {[@var{x}, @var{y}, @var{z}] =} sph2cart (@var{theta}, @var{phi}, @var{r})
 ## @deftypefnx {Function File} {[@var{x}, @var{y}, @var{z}] =} sph2cart (@var{S})
-## @deftypefnx {Function File} {C =} sph2cart (@dots{})
+## @deftypefnx {Function File} {@var{C} =} sph2cart (@dots{})
 ## Transform spherical to Cartesian coordinates.
 ##
 ## @var{theta} describes the angle relative to the positive x-axis.
 ## @var{phi} is the angle relative to the xy-plane.
 ## @var{r} is the distance to the origin @w{(0, 0, 0)}.
 ## @var{theta}, @var{phi}, and @var{r} must be the same shape, or scalar.
-## If called with a single matrix argument then each row of @var{s}
+## If called with a single matrix argument then each row of @var{S}
 ## represents the spherical coordinate (@var{theta}, @var{phi}, @var{r}).
 ##
 ## If only a single return argument is requested then return a matrix
@@ -66,11 +66,12 @@ function [x, y, z] = sph2cart (theta, phi, r)
   z = r .* sin (phi);
 
   if (nargout <= 1)
-    x = [x, y, z];
+    x = [x(:), y(:), z(:)];
   endif
 
 endfunction
 
+
 %!test
 %! t = [0, 0, 0];
 %! p = [0, 0, 0];
@@ -84,10 +85,10 @@ endfunction
 %! t = 0;
 %! p = [0, 0, 0];
 %! r = [0, 1, 2];
-%! [x, y, z] = sph2cart (t, p, r);
-%! assert (x, r);
-%! assert (y, [0, 0, 0]);
-%! assert (z, [0, 0, 0]);
+%! C = sph2cart (t, p, r);
+%! assert (C(:,1), r(:));
+%! assert (C(:,2), [0; 0; 0]);
+%! assert (C(:,3), [0; 0; 0]);
 
 %!test
 %! t = [0, 0, 0];
@@ -110,5 +111,5 @@ endfunction
 %!test
 %! S = [ 0, 0, 1; 0.5*pi, 0, 1; pi, 0, 1];
 %! C = [ 1, 0, 0; 0, 1, 0; -1, 0, 0];
-%! assert (sph2cart(S), C, eps);
+%! assert (sph2cart (S), C, eps);
 
