@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2011 John W. Eaton
+## Copyright (C) 2009-2013 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -32,15 +32,15 @@ function varargout = which (varargin)
       for i = 1:nargin
         if (isempty (m(i).file))
           if (! isempty (m(i).type))
-            printf ("`%s' is a %s\n",
+            printf ("'%s' is a %s\n",
                     m(i).name, m(i).type);
           endif
         else
           if (isempty (m(i).type))
-            printf ("`%s' is the file %s\n",
+            printf ("'%s' is the file %s\n",
                     m(i).name, m(i).file);
           else
-            printf ("`%s' is a %s from the file %s\n",
+            printf ("'%s' is a %s from the file %s\n",
                     m(i).name, m(i).type, m(i).file);
           endif
         endif
@@ -53,3 +53,14 @@ function varargout = which (varargin)
   endif
 
 endfunction
+
+
+%!test
+%! str = which ("ls");
+%! assert (str(end-17:end), strcat ("miscellaneous", filesep (), "ls.m"));
+%!test
+%! str = which ("amd");
+%! assert (str(end-6:end), "amd.oct");
+
+%!assert (which ("_NO_SUCH_NAME_"), "")
+
