@@ -1,4 +1,4 @@
-## Copyright (C) 2006, 2007 John W. Eaton
+## Copyright (C) 2006-2013 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -20,11 +20,16 @@
 ## @defvr {Automatic Variable} ans
 ## The most recently computed result that was not
 ## explicitly assigned to a variable.  For example, after the expression
-## 
+##
 ## @example
 ## 3^2 + 4^2
 ## @end example
-## 
+##
 ## @noindent
 ## is evaluated, the value returned by @code{ans} is 25.
 ## @end defvr
+
+
+## Mark file as being tested.  No real test needed for a documentation .m file
+%!assert (1)
+
