@@ -1,4 +1,4 @@
-## Copyright (C) 2004, 2005, 2006, 2007 John W. Eaton
+## Copyright (C) 2004-2013 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -18,8 +18,8 @@
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} ispc ()
-## Return 1 if Octave is running on a Windows system and 0 otherwise.
-## @seealso{ismac, isunix}
+## Return true if Octave is running on a Windows system and false otherwise.
+## @seealso{isunix, ismac}
 ## @end deftypefn
 
 function retval = ispc ()
@@ -31,3 +31,9 @@ function retval = ispc ()
   endif
 
 endfunction
+
+
+%!assert (islogical (ispc ()))
+
+%!error ispc (1)
+
