@@ -1,4 +1,4 @@
-## Copyright (C) 2003, 2005, 2007, 2008 John W. Eaton
+## Copyright (C) 2003-2013 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -29,11 +29,27 @@ function dirname = tempdir ()
   endif
 
   if (! strcmp (dirname(end), filesep))
-    strcat (dirname, filesep);
+    dirname = [dirname filesep];
   endif
 
   if (! isdir (dirname))
-    warning ("tempdir: `%s' does not exist or is not a directory", dirname);
+    warning ("tempdir: '%s' does not exist or is not a directory", dirname);
   endif
 
 endfunction
+
+
+%!assert (ischar (tempdir ()))
+
+%!test
+%! old_wstate = warning ("query");
+%! warning ("off");
+%! old_tmpdir = getenv ("TMPDIR");
+%! unwind_protect
+%!   setenv ("TMPDIR", "__MY_TMP_DIR__");
+%!   assert (tempdir (), ["__MY_TMP_DIR__" filesep()]);
+%! unwind_protect_cleanup
+%!   setenv ("TMPDIR", old_tmpdir);
+%!   warning (old_wstate);
+%! end_unwind_protect
+
