@@ -20,11 +20,12 @@
 ## @deftypefn  {Function File} {} spy (@var{x})
 ## @deftypefnx {Function File} {} spy (@dots{}, @var{markersize})
 ## @deftypefnx {Function File} {} spy (@dots{}, @var{line_spec})
-## Plot the sparsity pattern of the sparse matrix @var{x}.  If the argument
-## @var{markersize} is given as a scalar value, it is used to determine the
-## point size in the plot.  If the string @var{line_spec} is given it is
-## passed to @code{plot} and determines the appearance of the plot.
-## @seealso{plot}
+## Plot the sparsity pattern of the sparse matrix @var{x}.
+## 
+## If the argument @var{markersize} is given as a scalar value, it is used to
+## determine the point size in the plot.  If the string @var{line_spec} is
+## given it is passed to @code{plot} and determines the appearance of the plot.
+## @seealso{plot, gplot}
 ## @end deftypefn
 
 function spy (x, varargin)
@@ -34,7 +35,7 @@ function spy (x, varargin)
   endif
 
   markersize = NaN;
-  if (numel (x) < 1000)
+  if (nnz (x) < 1000)
     line_spec = "*";
   else
     line_spec = ".";
